@@ -1,17 +1,18 @@
 ## function for obtaining predictions
 def get_predictions_tfrec(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE, model, output_filename):
 	import numpy as np
-
+	from quick_ml.begin_tpu import get_test_dataset
 	testdata = get_test_dataset(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE)
 	images = testdata.map(lambda image, idnum : image)
 	ids = testdata.map(lambda image, idnum : idnum).unbatch()
 
 	NUM_TEST_IMAGES = 0
-	for data in testdata:
+	for data in testdata.unbatch():
 		NUM_TEST_IMAGES += 1
 
-	probabilities = model.predict(images)
-	predictions = np.argmax(probabilities,axis = 1)
+	#probabilities = model.predict(images)
+	#predictions = np.argmax(probabilities,axis = -1)
+	predictions = model.predict_classes(images)
 	print("Generating Output File...")
 	ids = next(iter(ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
 	np.savetxt(output_filename, np.rec.fromarrays([ids, predictions]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
@@ -24,11 +25,12 @@ def get_predictions(testTFdataset, model, output_filename):
 	test_ids = testTFdataset.map(lambda image, idnum : idnum).unbatch()
 
 	NUM_TEST_IMAGES = 0
-	for data in testTFdataset:
+	for data in testTFdataset.unbatch():
 		NUM_TEST_IMAGES += 1
 
-	probabilities = model.predict(images)
-	predictions = np.argmax(probabilities, axis = 1)
+	#probabilities = model.predict(images)
+	#predictions = np.argmax(probabilities, axis = -1)
+	predictions = model.predict_classes(images)
 	print("Generating Output File..")
 	test_ids = next(iter(test_ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
 	np.savetxt(output_filename, np.rec.fromarrays([test_ids, predictions]), fmt=['%s', '%d'], delimiter=',', header='id,label', comments='')
